@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
-from jinja2 import lexer, nodes
+from jinja2 import nodes
 from jinja2.ext import Extension
 from sass_processor.processor import SassProcessor
 
@@ -11,11 +8,7 @@ class SassSrc(Extension):
 
     def parse(self, parser):
         lineno = next(parser.stream).lineno
-
-        token = parser.stream.expect(
-            lexer.TOKEN_STRING
-        )
-        path = nodes.Const(token.value)
+        path = parser.parse_expression()
 
         call = self.call_method(
             '_sass_src_support', [
@@ -30,4 +23,4 @@ class SassSrc(Extension):
 
     def _sass_src_support(self, path, source_file):
         sass_processor = SassProcessor(source_file)
-        return sass_processor(path)
+        return SassProcessor.handle_simple(sass_processor(path))
